@@ -113,9 +113,11 @@ slog(Slog::levelDebug) <<name<<": sleepHandler event "<<event->id<<endl;
                 handler = &AculabTrunk::stepHandler;
                 return true;
         case TRUNK_CHILD_START:
-                setSymbol(data.sleep.save, 64);
-                setSymbol(data.sleep.save,
-                        event->parm.trunk->getSymbol(SYM_GID));
+		cp = event->parm.trunk->getSymbol(SYM_GID);
+		if(cp)
+			cp = strchr(cp, '-');
+		if(cp)
+	                setVariable(data.sleep.save, 16, cp);
                 trunkSignal(TRUNK_SIGNAL_STEP);
                 handler = &AculabTrunk::stepHandler;
                 return true;
@@ -130,8 +132,7 @@ slog(Slog::levelDebug) <<name<<": sleepHandler event "<<event->id<<endl;
 				value = strchr(cp, '=');
 				if(value) {
 					*(value++) = 0;
-					setSymbol(cp, getSymbolSize());
-					setSymbol(cp, value);
+					setVariable(cp, 0, value);
 				}
 				cp = strtok_r(NULL, "&", &sp);
 			}
