@@ -385,7 +385,7 @@ Driver(), Thread(keythreads.priService() - 1)
                                 switch(iface)
                                 {
                                         case NT_E1:
-                                                if(dti > dticount+1)
+                                                if(dti > dticount)
 						{
 							++dticard;
                                                         dti = 0;
@@ -1168,6 +1168,7 @@ void DialogicDriver::run(void)
 					case DTE1_CECSOK:
 						slog(Slog::levelError) << "dialogic: DTEV_T1ERRC - DTE1_CECSOK : CRC4 error count saturation recovered" << endl;
 						break;
+#ifdef	DTE1_REDOK
 					case DTE1_REDOK:
 						slog(Slog::levelError) << "dialogic: DTEV_T1ERRC - DTE1_REDOK : Red alarm recovered" << endl;
 						break;
@@ -1180,6 +1181,7 @@ void DialogicDriver::run(void)
 					case DTE1_CRC_CFAOK:
 						slog(Slog::levelError) << "dialogic: DTEV_T1ERRC - DTE1_CRC_CFAOK : Timeslot 16 CRC failure recovered" << endl;
 						break;
+#endif
 					default:
 						slog(Slog::levelError) << "dialogic: DTEV_T1ERRC - default : " << endl;
 						break;
