@@ -46,6 +46,8 @@ extern "C" {
 };
 
 #include "driver.h"
+#include "possibilite.h"
+#include "reroute.h"
 
 #define	EVENT_BUFFER_SIZE	16
 
@@ -139,8 +141,9 @@ TimerPort(), Trunk(id, 0, devif->span), Thread(0), URLAudio(), AudioService()
 		{
 			if(cc_SetEvtMsk(tsdev, CCMSK_ALERT | CCMSK_PROCEEDING | CCMSK_PROGRESS | CCMSK_SETUP_ACK, CCACT_ADDMSK) < 0)
 				putISDNError("cc_SetEvtMsk");
-		//	if(cc_SetParm(tsdev, RECEIVE_INFO_BUF, 20) < 0)
-		//		putISDNError("cc_SetParm");
+			/* Set the channel parameters to be able to receive IE buffers */
+			if(cc_SetParm(tsdev, RECEIVE_INFO_BUF, 100) < 0)
+				putISDNError("cc_SetParm");
 		}
 	RELEASE
 
@@ -1245,9 +1248,14 @@ int DialogicTrunk::getISDNInfo(int mode, unsigned char *cid)
 {
 	int rtn;
 	int mdig;
+
+	Possibilite *ptPos;
+
 	if(!isdn)
 		return getCallerId(mode, cid);
 
+	ptPos = (Possibilite *) cid;
+
 	HOLD("cid")
 		switch(mode)
 		{
@@ -1266,6 +1274,14 @@ int DialogicTrunk::getISDNInfo(int mode, unsigned char *cid)
 		case MCLASS_DN:
 			rtn = cc_GetANI(crn, (char *)cid);
 			break;
+		case MCLASS_POSSIBILITE:
+			//strcpy((char *) cid, callednasposs);
+			strcpy(ptPos->appele, callednasposs);
+			strcpy(ptPos->appelant, callingnasposs);
+			strcpy(ptPos->retour, retourposs);
+			strcpy(ptPos->contexte, contextposs);
+			rtn = 0;
+			break;
 		default:
 			rtn = -1;
 		}
@@ -1401,6 +1417,236 @@ bool DialogicTrunk::scrWait(void)
         return false;
 }
 
+ 
+bool DialogicTrunk::scrReroute(void)
+{
+	const char *option = getMember();
+	char *forwarddest = NULL;
+	char *backwarddest = NULL;
+	char *context = NULL;
+	char *backcontext = NULL;
+
+	// Parse the arguments
+	Line *line = getScript();
+	for (unsigned int argc = 0 ; argc < line->argc ; argc++) {
+		if (!strcmp(line->args[argc], "=forwarddest")) {
+
+			forwarddest = line->args[++argc];
+			if (forwarddest[0] == '%') {
+				forwarddest = getContent(forwarddest);
+			}
+			if (strlen(forwarddest) > sizeof(data.reroute.forwarddest) - 1) {
+				forwarddest[sizeof(data.reroute.forwarddest)] = 0;
+			}
+			strcpy(data.reroute.forwarddest, forwarddest);
+		}
+		if (!strcmp(line->args[argc], "=backwarddest")) {
+
+			backwarddest = line->args[++argc];
+			if (backwarddest[0] == '%') {
+				backwarddest = getContent(backwarddest);
+			}
+			if (strlen(backwarddest) > sizeof(data.reroute.backwarddest) - 1) {
+				backwarddest[sizeof(data.reroute.backwarddest)] = 0;
+			}
+			strcpy(data.reroute.backwarddest, backwarddest);
+		}
+
+		if (!strcmp(line->args[argc], "=context")) {
+
+			context = line->args[++argc];
+			if (context[0] == '%') {
+				context = getContent(context);
+			}
+			if (strlen(context) > sizeof(data.reroute.context) - 1) {
+				context[sizeof(data.reroute.context)] = 0;
+			}
+			strcpy(data.reroute.context, context);
+		}
+		if (!strcmp(line->args[argc], "=backcontext")) {
+
+			backcontext = line->args[++argc];
+			if (backcontext[0] == '%') {
+				backcontext = getContent(backcontext);
+			}
+			if (strlen(backcontext) > sizeof(data.reroute.backcontext) - 1) {
+				backcontext[sizeof(data.reroute.backcontext)] = 0;
+			}
+			strcpy(data.reroute.backcontext, backcontext);
+		}
+	}
+
+	// Default behavior
+	if (!option) {
+		strcpy(data.reroute.option, "1");
+	}
+	else {
+		if (strlen(option) > sizeof(data.reroute.option) - 1) {
+			strncpy(data.reroute.option, option, sizeof(data.reroute.option) - 1);
+			data.reroute.option[sizeof(data.reroute.option) - 1] = 0;
+		}
+		else {
+			strcpy(data.reroute.option, option);
+		}
+	}
+	slog(Slog::levelDebug) << "scrReroute  option = " << data.reroute.option << endl ;
+	{
+		reroutage_t r;
+		unsigned char trameReroutage[128];
+		int len, res;
+		IE_BLK    ie_blk;
+		
+		initReroute(&r);
+
+		// Set forward characteristics :
+
+		switch (atoi(data.reroute.option)) {
+			case 1:
+				setType(&r, REROUTAGE_NAS_GTX); 
+				setNumero(&r, PARAM_NUM,  (unsigned char *) data.reroute.forwarddest );
+				break;
+			case 2:
+				setType(&r, REROUTAGE_NAB_GTX); 
+				setNumero(&r, PARAM_NAB,  (unsigned char *) data.reroute.forwarddest );
+				break;
+			case 3:
+				setType(&r, REROUTAGE_ANNUAIRE); 
+				break;
+			case 4:
+				setType(&r, REROUTAGE_NTR_NAS); 
+				break;
+			case 5:
+				setType(&r, REROUTAGE_INDEFINI); 
+				break;
+			case 6:
+				setType(&r, REROUTAGE_NONTRANSPARENT); 
+				break;
+			default :
+				slog(Slog::levelError) << "Unknown forwarding type - switched to default " << endl ;
+				setType(&r, REROUTAGE_NAS_GTX); 
+				break;
+		}
+
+		setCascade(&r, 1); 
+
+		if (context)
+			setContexte(&r, PARAM_CONTEXTE_ASCII, (unsigned char *) data.reroute.context);
+		if (backcontext)
+			setRetour(&r, (unsigned char *) data.reroute.backcontext);
+		if (backwarddest)
+			setNasRetour(&r, (unsigned char *) data.reroute.backwarddest);
+
+		// Build the packet :
+		len = makeTrame(&r, trameReroutage);
+		ie_blk.length = len + 7;
+		memcpy(ie_blk.data, trameReroutage, len + 7);
+		slog(Slog::levelDebug) << "Forward to " << data.reroute.forwarddest << " (" << data.reroute.context << ")" << endl ;
+		// and send it :
+		res = cc_SndMsg(crn,  SndMsg_Facility , &ie_blk);
+		if (res != 0)
+			slog(Slog::levelError) << "cc_SndMsg failure : " << res << endl ;
+	}
+
+        trunkStep(TRUNK_STEP_REROUTE);
+	return false;
+}
+
+bool DialogicTrunk::scrConference(void)
+{
+	const char *option = getMember();
+	char *name = NULL;
+	char *size = NULL;
+	unsigned int sz = 1;
+	char *attr = NULL;
+	int attributes = MSPA_NULL;
+	unsigned int fixed = 0;
+	data.conference.option = CONF_UNKNOWN;
+
+	// Analyze the arguments
+	Line *line = getScript();
+	for (unsigned int argc = 0 ; argc < line->argc ; argc++) {
+		if (!strcmp(line->args[argc], "=name")) {
+
+			// Name of the conference
+			name = line->args[++argc];
+			if (name[0] == '%') {
+				name = getContent(name);
+			}
+			if (strlen(name) > 255) {
+				name[255] = 0;
+			}
+		}
+		if (!strcmp(line->args[argc], "=size")) {
+
+			// Number of conferees
+			size = line->args[++argc];
+			if (size[0] == '%') {
+				size = getContent(size);
+			}
+			if (size != NULL) {
+				sz = (unsigned int)atoi(size);
+				if (sz == 0) sz = 1;
+			}
+		}
+		if (!strcmp(line->args[argc], "=attr")) {
+
+			// Attributes
+			attr = line->args[++argc];
+			if (attr[0] == '%') {
+				attr = getContent(attr);
+			}
+			if (attr != NULL) {
+				if (strstr(attr, "ro") != NULL) {
+					attributes |= MSPA_RO;
+				}
+				if (strstr(attr, "periodicTone") != NULL) {
+					attributes |= MSPA_TARIFF;
+				}
+				if (strstr(attr, "fixed") != NULL) {
+					fixed = 1;
+				}
+			}
+		}
+	}
+
+	// Behavior
+	if (!option) {
+		data.conference.option = CONF_DEFAULT;
+		data.conference.size = sz;
+		data.conference.attributes = attributes;
+		data.conference.fixed = fixed;
+	}
+	else
+	if (!strcmp(option, "enter")) {
+		data.conference.option = CONF_ENTER;
+		data.conference.size = sz;
+		data.conference.attributes = attributes;
+		data.conference.fixed = fixed;
+	}
+	else
+	if (!strcmp(option, "leave")) {
+		data.conference.option = CONF_LEAVE;
+	}
+	else
+	if (!strcmp(option, "establish")) {
+		data.conference.option = CONF_ESTABLISH;
+		data.conference.size = sz;
+		data.conference.attributes = attributes;
+		data.conference.fixed = fixed;
+	}
+	else
+	if (!strcmp(option, "destroy")) {
+		data.conference.option = CONF_DESTROY;
+	}
+	else {
+		data.conference.option = CONF_UNKNOWN;
+	}
+	if (name ==NULL) data.conference.name[0] = 0;
+	else strncpy(data.conference.name, name, 255);
+        trunkStep(TRUNK_STEP_CONFERENCE);
+	return false;
+}
+
 #ifdef CCXX_NAMESPACES
 };
 #endif
