@@ -84,9 +84,11 @@ bool DummyTrunk::sleepHandler(TrunkEvent *event)
                 handler = &DummyTrunk::stepHandler;
                 return true;
         case TRUNK_CHILD_START:
-                setSymbol(data.sleep.save, 64);
-                setSymbol(data.sleep.save,
-                        event->parm.trunk->getSymbol(SYM_GID));
+		cp = event->parm.trunk->getSymbol(SYM_GID);
+		if(cp)
+			cp = strchr(cp, '-');
+		if(cp)
+			setVariable(data.sleep.save, 16, cp);
                 trunkSignal(TRUNK_SIGNAL_STEP);
                 handler = &DummyTrunk::stepHandler;
                 return true;
@@ -104,8 +106,7 @@ bool DummyTrunk::sleepHandler(TrunkEvent *event)
 				if(value)
 				{
 					*(value++) = 0;
-					setSymbol(cp, getSymbolSize());
-					setSymbol(cp, value);
+					setVariable(cp, 0, value);
 				}
 				cp = strtok_r(NULL, "&", &sp);
 			}
