@@ -68,16 +68,15 @@ bool DialogicTrunk::acceptHandler(TrunkEvent *event)
 		}
 		status[id] = 'r';
 		enterState("accept");
+
 		if(!callProgress(IN_BAND_INFO) || !acceptCall())
 		{
 			TimerPort::endTimer();
 			Trunk::flags.dsp = DSP_MODE_INACTIVE;
 			trunkSignal(TRUNK_SIGNAL_HANGUP);
+			handler = &DialogicTrunk::hangupHandler;
 			return false;
 		}
-		//else
-		//	trunkSignal(TRUNK_SIGNAL_GOTO);
-		//handler = &DialogicTrunk::stepHandler;
 		return true;
 	case TRUNK_CALL_ACCEPT:
 		trunkSignal(TRUNK_SIGNAL_GOTO);
