@@ -74,13 +74,18 @@ Keydata("/bayonne/dialogic")
 	{"l1protocol", "alaw"},
 	{NULL, NULL}};
 
+	const char *cp;
+
 	if(isFHS())
 		load("/drivers/dialogic");
 
 	load(defkeys);
-}
 
-#include "possibilite.c"
+	hangup_timer = 1000;
+	cp = getLast("hangup");
+	if(cp)
+		hangup_timer = atoi(cp);
+}
 
 const char *DialogicConfig::getSpanProtocol(void)
 {
@@ -218,24 +223,15 @@ Driver(), Thread(keythreads.priService() - 1)
 	static Script::Define keywords[] = {
 		{"join", (Method)&DialogicTrunk::scrJoin, &ScriptCommand::chkHasArgs},
 		{"wait", (Method)&DialogicTrunk::scrWait, &ScriptCommand::chkHasArgs},
-		{"reroute", (Method)&DialogicTrunk::scrReroute, &ScriptCommand::chkHasArgs},
-		{"conference", (Method)&DialogicTrunk::scrConference, &ScriptCommand::chkHasArgs},
 		{NULL, NULL, NULL}};
 
 	int boardtype;
 	int card = 0;
 	int vox = 0;
-	int id = 0, queue;
+	int id = 0;
 	unsigned i, s, portidx;
 	GC_CCLIB_STATUSALL cclibstatus;
 	GC_INFO gcinfo;
-	const char *cp = getLast("queue");
-
-	GC_PARM gcparm;
-	int gc_err;
-	int cclibid;
-	long cclib_err;
-	char *msg;
 
 	level = 0;
 	status = DialogicTrunk::status;
@@ -259,13 +255,6 @@ Driver(), Thread(keythreads.priService() - 1)
 	memset(devmap, 0, sizeof(devices_t) * port_count);
 	memset(spanmaps, 0, sizeof(DialogicISDN *) * getSpanCount());
 
-	if(cp)
-	{
-		queue = atoi(cp);
-		sr_setparm(SRL_DEVICE, SR_QSIZEID, &queue);
-		slog(Slog::levelDebug) << "dialogic: event queue depth set to " << queue << endl;
-	}
-
 #ifndef	SIGNAL
 	slog(Slog::levelDebug) << "globalcall: setting polled mode" << endl;
 	mode = SR_POLLMODE;
@@ -376,15 +365,8 @@ Driver(), Thread(keythreads.priService() - 1)
 		// SR5.1 + a JCT card with this enabled will not detect hangups.
 		// Possibly also the cause of missing hangup on SP1 aswell with the
 		// same board.
-		// gc_SetEvtMsk(devmap[portidx].linedev, GCMSK_ALERTING | GCMSK_BLOCKED |
-			// GCMSK_DIALING | GCMSK_PROCEEDING | GCMSK_UNBLOCKED, GCACT_SETMSK);
-
-		gcparm.longvalue = 100;  
-		if (gc_SetParm (devmap[portidx].linedev, RECEIVE_INFO_BUF, gcparm) != GC_SUCCESS)  {  
-			gc_ErrorValue(&gc_err, &cclibid, &cclib_err);  
-			gc_ResultMsg(cclibid, cclib_err, &msg);  
-			slog(Slog::levelError) << "Error on SetParm - " << devmap[portidx].linedev << " : " << msg << " (" << cclib_err << ")" << endl;
-		}
+		//gc_SetEvtMsk(devmap[portidx].linedev, GCMSK_ALERTING | GCMSK_BLOCKED |
+		//	GCMSK_DIALING | GCMSK_PROCEEDING | GCMSK_UNBLOCKED, GCACT_SETMSK);
 
 		++id;
 	   }
@@ -415,7 +397,6 @@ Driver(), Thread(keythreads.priService() - 1)
 	ScriptCommand::load(keywords);
 				
 	slog(Slog::levelInfo) << "Globalcall driver loaded; capacity=" << id << endl;
-	slog(Slog::levelDebug) << "maxconference= " << DialogicDCB::detect() << endl;
 	port_used = id;
 }
 
@@ -513,19 +494,6 @@ void DialogicDriver::run(void)
 	METAEVENT metaevent;
 	char buffer[16];
 
-	IE_BLK ie_blk;
-	char bufPos[64 + 1];
-	char NAS[20 + 1];
-	char CTX[20 + 1];
-	char APPELANT[20 + 1];
-	char RETOUR[20 + 1];
-	int boucle, lenPos;
-	int gc_err;
-	int cclibid;
-	long cclib_err;
-	char *msg;
-	GC_PARM gcparm;
-
 #ifdef	COMMON_THREAD_SLEEP
 	Thread::sleep(2000);
 #else
@@ -554,7 +522,7 @@ void DialogicDriver::run(void)
 		evdev = metaevent.evtdev;
 		linedev = metaevent.linedev;
 
-		// slog(Slog::levelDebug) << "got event " << hex << evtype << endl;
+		//slog(Slog::levelDebug) << "got event " << hex << evtype << endl;
 
 		if(metaevent.flags & GCME_GC_EVENT)
 			trunk = maps[linedev];
@@ -575,7 +543,6 @@ void DialogicDriver::run(void)
 		case GCEV_FATALERROR:
 		case GCEV_TASKFAIL:
 			event.id = TRUNK_CALL_FAILURE;
-			EventError(&metaevent);
 			trunk->postEvent(&event);
 			break;
 		case GCEV_BLOCKED:
@@ -593,7 +560,7 @@ void DialogicDriver::run(void)
 			trunk->postEvent(&event);
 			break;
 		case GCEV_RESETLINEDEV:
-			trunk->crn = -1;
+//			trunk->crn = -1;
 			event.id = TRUNK_CALL_RESTART;
 			event.parm.ok = true;
 			trunk->postEvent(&event);
@@ -608,44 +575,6 @@ void DialogicDriver::run(void)
 			trunk->postEvent(&event);
 			break;
 		case GCEV_OFFERED:
-			// Modification to extract Commande Possibilite
-			strcpy(trunk->callednasposs, "UNKNOWN");
-			strcpy(trunk->callingnasposs, "UNKNOWN");
-			strcpy(trunk->contextposs, "NONE");
-			strcpy(trunk->retourposs, "NONE");
-
-			if (gc_GetSigInfo(linedev, (char *)&ie_blk, U_IES, &metaevent) != GC_SUCCESS) {
-				gc_ErrorValue(&gc_err, &cclibid, &cclib_err);  
-				gc_ResultMsg(cclibid, cclib_err, &msg);
-				slog(Slog::levelError) << "Error on GetSigInfo - " << linedev << " : " << msg << " (" << gc_err << ")" << endl;
-			} else {
-				slog(Slog::levelDebug) << "SigInfo length= " << ie_blk.length << endl;
-				for (boucle = 0 ; boucle < ie_blk.length; boucle++)
-					slog(Slog::levelDebug) << hex << (int) ie_blk.data[boucle] << endl;
-
-				/* Extract "Command Possibilit" from the ie block data */
-				if ((lenPos = extraitPossibilite(ie_blk.data, bufPos, ie_blk.length)) > 0) {
-					if (extraitInfosPossibilite(bufPos, NAS, APPELANT, CTX, RETOUR, lenPos) >= 0)  {
-						strcpy(trunk->callednasposs, NAS);
-						strcpy(trunk->callingnasposs, APPELANT);
-						strcpy(trunk->contextposs, CTX);
-						strcpy(trunk->retourposs, RETOUR);
-					}
-				} else slog(Slog::levelDebug) << "No commande Possibilite" << endl;
-			}
-			// End of modification
-
-
-                        // Modif: Detect and store a second CRN due to multiple call on one line 
-                        trunk->crn_hold = -1;
-                        if(trunk->crn != -1){
-                         trunk->crn_hold = metaevent.crn;
-                        }
-                        else{
-                         trunk->crn = metaevent.crn;
-                        }
-                        // End Modif 
-
 			trunk->crn = metaevent.crn;
 			event.id = TRUNK_CALL_OFFER;
 			trunk->postEvent(&event);
@@ -820,15 +749,14 @@ void DialogicDriver::run(void)
 			case TDX_CALLP:
 				switch(event.id)
 				{
-					case TRUNK_CPA_NOANSWER:
-					case TRUNK_CPA_NODIALTONE:
-					case TRUNK_CPA_NORINGBACK:
-					case TRUNK_CPA_FAILURE:
-					case TRUNK_CPA_BUSYTONE:
-						break;
-
-					default:
-						event.id = TRUNK_TONE_IDLE;
+				case TRUNK_CPA_NOANSWER:
+				case TRUNK_CPA_NODIALTONE:
+				case TRUNK_CPA_NORINGBACK:
+				case TRUNK_CPA_FAILURE:
+				case TRUNK_CPA_BUSYTONE:
+					break;
+				default:
+					event.id = TRUNK_TONE_IDLE;
 				}
 				break;
 			case TDX_PLAY:
@@ -842,8 +770,6 @@ void DialogicDriver::run(void)
 			event.id = TRUNK_TIMER_EXPIRED;
 			trunk->putEvent(&event);
 			break;
-		case CCEV_SETCHANSTATE:
-			break;
 		default:
 			slog(Slog::levelDebug) << "globalcall: unhandled event 0x" << hex << evtype << endl;
 		}
