@@ -47,8 +47,6 @@ extern "C" {
 #include <strstream>
 //#include <cc++/xml.h>
 #include "driver.h"
-#include "possibilite.h"
-#include "reroute.h"
 
 #define	EVENT_BUFFER_SIZE	16
 
@@ -181,6 +179,8 @@ TimerPort(), Trunk(id, 0, devif->span), Thread(0), URLAudio(), AudioService()
 		if(dx_setparm(chdev, DXCH_MAXRWINK, (void *)&bparm))
 			postError(chdev, "dx_setparm");
 	}
+
+	_clearing = false;
 				
 //	(this->*handler)(&event);
 }
@@ -586,12 +586,26 @@ retry:
 			setDTMFDetect(false);
 		TimerPort::endTimer();
 		break;
+	//+++ IMMEDIATE HANGUP, REQUIRES CALL CLEARING INSTEAD!!!!
+	case TRUNK_CALL_FAILURE:
+	case TRUNK_CALL_RESTART:
+		resetChannel();
+	case TRUNK_STOP_DISCONNECT:
+		if(!_clearing)
+			hangupCall();
+		_clearing = true;
+		if(Trunk::flags.onexit)
+			break;
+		if(trunkSignal(TRUNK_SIGNAL_HANGUP))
+		{
+			event->id = TRUNK_STOP_STATE;
+			goto retry;
+		}
+		break;	
 	case TRUNK_LINE_WINK:
 		if(!Trunk::flags.offhook)
 			break;
 	case TRUNK_CPA_DIALTONE:
-	case TRUNK_STOP_DISCONNECT:
-	case TRUNK_CALL_FAILURE:
 		if(Trunk::flags.onexit)
 			break;
 		if(trunkSignal(TRUNK_SIGNAL_HANGUP))
@@ -682,19 +696,19 @@ void DialogicTrunk::postGCError(const char *msg)
 
 void DialogicTrunk::postGCError2(const char *msg)
 {
-	char buffer[33];
-	int gc_error;
-	GC_INFO t_Info;
+        char buffer[33];
+        int gc_error;
+        GC_INFO t_Info;
 
-	getName(buffer);
-	gc_error = gc_ErrorInfo(&t_Info);
-	if (gc_error == GC_SUCCESS) {
+        getName(buffer);
+        gc_error = gc_ErrorInfo(&t_Info);
+        if (gc_error == GC_SUCCESS) 
+	{
 		slog(Slog::levelError) << buffer << ": error retrieved OK " << endl;
 		slog(Slog::levelError) << buffer << ": value: " << t_Info.gcValue << " msg: " << t_Info.gcMsg << " add: " << t_Info.additionalInfo << endl;
-	} else {
+        } else {
 		slog(Slog::levelError) << buffer << ": error retrieved KO " << endl;
-	}
-
+        }
 }
 
 void DialogicTrunk::exit(void)
@@ -772,19 +786,14 @@ bool DialogicTrunk::waitCall(void)
 bool DialogicTrunk::callProgress(int indicator)
 {
 	char buffer[33];
-	int state = -1;
 	getName(buffer);
-	gc_GetCallState(crn, &state);
-	slog(Slog::levelDebug) << buffer << "State:: " << state << endl;
 
 	getName(buffer);
-	slog(Slog::levelDebug) << buffer << "CALLPROGRESS!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!" << endl;
-	slog(Slog::levelDebug) << buffer << "trunk.cpp callProgress: begin" << endl;
 
 	if(gc_CallProgress(crn, indicator) == GC_SUCCESS)
 		return true;
-	else
-		return false;
+
+	return false;
 }
 
 bool DialogicTrunk::acceptCall(void)
@@ -823,9 +832,10 @@ bool DialogicTrunk::hangupCall(void)
 	int cause;
 
 	if(!Trunk::flags.offhook && !_accepted)
+	{
+		releaseCall();
 		return false;
-
-	_disconnecting = true;
+	}
 
 	switch(callstate)
 	{
@@ -839,14 +849,17 @@ bool DialogicTrunk::hangupCall(void)
 
 	if(crn != -1)
 	{
-		if(gc_DropCall(crn, cause, EV_ASYNC) < 0)
+		_disconnecting = true;
+		if(gc_DropCall(crn, cause, EV_ASYNC) != GC_SUCCESS)
 		{
-			resetChannel();
+			releaseCall();
+			Trunk::flags.offhook = false;
 			postGCError("gc_DropCall");
 			return false;
 		}
 	}
-	else resetChannel();
+	else
+		releaseCall();
 
 	Trunk::flags.offhook = false;
 	return true;
@@ -856,30 +869,26 @@ void DialogicTrunk::releaseCall(void)
 {
 	_disconnecting = false;
 
-	if(gc_ReleaseCallEx(crn, EV_ASYNC) < 0)
+	if(crn != -1)
 	{
-		int state;
-
-		gc_GetCallState(crn, &state);
-		slog(Slog::levelDebug) << buffer << "trunk.cpp releaseCall: releasing CRN: " << crn << " FAILED state=" << state << endl;
-		postGCError("gc_ReleaseCallEx");
+		if(gc_ReleaseCallEx(crn, EV_ASYNC) != GC_SUCCESS)
+			postGCError("gc_ReleaseCallEx");
 	}
-	else slog(Slog::levelDebug) << buffer << "trunk.cpp releaseCall: releasing CRN: " << crn << " OK state=" << state << endl;
-
 	
+	crn = -1;
+	resetChannel();
 }
 
 void DialogicTrunk::resetChannel(void)
 {
-	gc_ResetLineDev(linedev, EV_ASYNC);
+	if(!_clearing)	
+		gc_ResetLineDev(linedev, EV_ASYNC);
+	_clearing = true;
+	stopChannel(EV_ASYNC);
 }
 
 bool DialogicTrunk::makeCall(char digit[16], int timeout)
 {
-	char buffer[33];
-	
-	getName(buffer);
-	
 	MAKECALL_BLK makecall_blk;
 	GC_MAKECALL_BLK gclib_blk;
 	int rtn = 0;
@@ -918,11 +927,12 @@ bool DialogicTrunk::makeCall(char digit[16], int timeout)
 
 	rtn = gc_MakeCall(linedev, &crn, digit, &gclib_blk, 0, EV_ASYNC);
 
-	if(rtn < 0) crn = -1;
+	if(rtn != GC_SUCCESS)
+		crn = -1;
+
 	if(crn <= 0)
 	{
-		slog(Slog::levelError) << buffer << ": makeCall error: crn <= 0. Going to reset line" << endl;
-		gc_ResetLineDev(linedev, EV_ASYNC);
+		releaseCall();
 		postGCError2("gc_MakeCall");
 		return false;
 	}
@@ -1058,14 +1068,6 @@ void DialogicTrunk::getCallerId(void)
 		setConst(SYM_DIALED, (char *)cid);
 		setConst(SYM_DNID, (char *)cid + 5);
 	}
-
-
-	setConst("session.callednaspos", callednasposs);
-	setConst("pstn.callednaspos", callednasposs);
-	setConst("pstn.callingnaspos", callingnasposs);
-	setConst("pstn.contextepos", contextposs);
-	setConst("pstn.retourpos", retourposs);
-
 }
 
 char *DialogicTrunk::getContinuation(void)
@@ -1195,235 +1197,6 @@ bool DialogicTrunk::scrWait(void)
         trunkStep(TRUNK_STEP_JOIN);
         return false;
 }
- 
-bool DialogicTrunk::scrReroute(void)
-{
-	const char *option = getMember();
-	char *forwarddest = NULL;
-	char *backwarddest = NULL;
-	char *context = NULL;
-	char *backcontext = NULL;
-
-	// Parse the arguments
-	Line *line = getScript();
-	for (unsigned int argc = 0 ; argc < line->argc ; argc++) {
-		if (!strcmp(line->args[argc], "=forwarddest")) {
-
-			forwarddest = line->args[++argc];
-			if (forwarddest[0] == '%') {
-				forwarddest = getContent(forwarddest);
-			}
-			if (strlen(forwarddest) > sizeof(data.reroute.forwarddest) - 1) {
-				forwarddest[sizeof(data.reroute.forwarddest)] = 0;
-			}
-			strcpy(data.reroute.forwarddest, forwarddest);
-		}
-		if (!strcmp(line->args[argc], "=backwarddest")) {
-
-			backwarddest = line->args[++argc];
-			if (backwarddest[0] == '%') {
-				backwarddest = getContent(backwarddest);
-			}
-			if (strlen(backwarddest) > sizeof(data.reroute.backwarddest) - 1) {
-				backwarddest[sizeof(data.reroute.backwarddest)] = 0;
-			}
-			strcpy(data.reroute.backwarddest, backwarddest);
-		}
-
-		if (!strcmp(line->args[argc], "=context")) {
-
-			context = line->args[++argc];
-			if (context[0] == '%') {
-				context = getContent(context);
-			}
-			if (strlen(context) > sizeof(data.reroute.context) - 1) {
-				context[sizeof(data.reroute.context)] = 0;
-			}
-			strcpy(data.reroute.context, context);
-		}
-		if (!strcmp(line->args[argc], "=backcontext")) {
-
-			backcontext = line->args[++argc];
-			if (backcontext[0] == '%') {
-				backcontext = getContent(backcontext);
-			}
-			if (strlen(backcontext) > sizeof(data.reroute.backcontext) - 1) {
-				backcontext[sizeof(data.reroute.backcontext)] = 0;
-			}
-			strcpy(data.reroute.backcontext, backcontext);
-		}
-	}
-
-	// Default behavior
-	if (!option) {
-		strcpy(data.reroute.option, "1");
-	}
-	else {
-		if (strlen(option) > sizeof(data.reroute.option) - 1) {
-			strncpy(data.reroute.option, option, sizeof(data.reroute.option) - 1);
-			data.reroute.option[sizeof(data.reroute.option) - 1] = 0;
-		}
-		else {
-			strcpy(data.reroute.option, option);
-		}
-	}
-	slog(Slog::levelDebug) << "scrReroute  option = " << data.reroute.option << endl ;
-	{
-		reroutage_t r;
-		unsigned char trameReroutage[128];
-		int len, res;
-		IE_BLK    ie_blk;
-		
-		initReroute(&r);
-
-		// Set forward characteristics :
-
-		switch (atoi(data.reroute.option)) {
-			case 1:
-				setType(&r, REROUTAGE_NAS_GTX); 
-				setNumero(&r, PARAM_NUM,  (unsigned char *) data.reroute.forwarddest );
-				break;
-			case 2:
-				setType(&r, REROUTAGE_NAB_GTX); 
-				setNumero(&r, PARAM_NAB,  (unsigned char *) data.reroute.forwarddest );
-				break;
-			case 3:
-				setType(&r, REROUTAGE_ANNUAIRE); 
-				break;
-			case 4:
-				setType(&r, REROUTAGE_NTR_NAS); 
-				break;
-			case 5:
-				setType(&r, REROUTAGE_INDEFINI); 
-				break;
-			case 6:
-				setType(&r, REROUTAGE_NONTRANSPARENT); 
-				break;
-			default :
-				slog(Slog::levelError) << "Unknown forwarding type - switched to default " << endl ;
-				setType(&r, REROUTAGE_NAS_GTX); 
-				break;
-		}
-
-		setCascade(&r, 1); 
-
-		if (context)
-			setContexte(&r, PARAM_CONTEXTE_ASCII, (unsigned char *) data.reroute.context);
-		if (backcontext)
-			setRetour(&r, (unsigned char *) data.reroute.backcontext);
-		if (backwarddest)
-			setNasRetour(&r, (unsigned char *) data.reroute.backwarddest);
-
-		// Build the packet :
-		len = makeTrame(&r, trameReroutage);
-		ie_blk.length = len + 7;
-		memcpy(ie_blk.data, trameReroutage, len + 7);
-		slog(Slog::levelDebug) << "Forward to " << data.reroute.forwarddest << " (" << data.reroute.context << ")" << endl ;
-		// and send it :
-		res = cc_SndMsg(crn,  SndMsg_Facility , &ie_blk);
-		if (res != 0)
-			slog(Slog::levelError) << "cc_SndMsg failure : " << res << endl ;
-	}
-
-        trunkStep(TRUNK_STEP_REROUTE);
-	return false;
-}
-
-bool DialogicTrunk::scrConference(void)
-{
-	const char *option = getMember();
-	char *name = NULL;
-	char *size = NULL;
-	unsigned int sz = 1;
-	char *attr = NULL;
-	int attributes = MSPA_NULL;
-	unsigned int fixed = 0;
-	data.conference.option = CONF_UNKNOWN;
-
-	// Analyze the arguments
-	Line *line = getScript();
-	for (unsigned int argc = 0 ; argc < line->argc ; argc++) {
-		if (!strcmp(line->args[argc], "=name")) {
-
-			// Name of the conference
-			name = line->args[++argc];
-			if (name[0] == '%') {
-				name = getContent(name);
-			}
-			if (strlen(name) > 255) {
-				name[255] = 0;
-			}
-		}
-		if (!strcmp(line->args[argc], "=size")) {
-
-			// Number of conferees
-			size = line->args[++argc];
-			if (size[0] == '%') {
-				size = getContent(size);
-			}
-			if (size != NULL) {
-				sz = (unsigned int)atoi(size);
-				if (sz == 0) sz = 1;
-			}
-		}
-		if (!strcmp(line->args[argc], "=attr")) {
-
-			// Attributes
-			attr = line->args[++argc];
-			if (attr[0] == '%') {
-				attr = getContent(attr);
-			}
-			if (attr != NULL) {
-				if (strstr(attr, "ro") != NULL) {
-					attributes |= MSPA_RO;
-				}
-				if (strstr(attr, "periodicTone") != NULL) {
-					attributes |= MSPA_TARIFF;
-				}
-				if (strstr(attr, "fixed") != NULL) {
-					fixed = 1;
-				}
-			}
-		}
-	}
-
-	// Behavior
-	if (!option) {
-		data.conference.option = CONF_DEFAULT;
-		data.conference.size = sz;
-		data.conference.attributes = attributes;
-		data.conference.fixed = fixed;
-	}
-	else
-	if (!strcmp(option, "enter")) {
-		data.conference.option = CONF_ENTER;
-		data.conference.size = sz;
-		data.conference.attributes = attributes;
-		data.conference.fixed = fixed;
-	}
-	else
-	if (!strcmp(option, "leave")) {
-		data.conference.option = CONF_LEAVE;
-	}
-	else
-	if (!strcmp(option, "establish")) {
-		data.conference.option = CONF_ESTABLISH;
-		data.conference.size = sz;
-		data.conference.attributes = attributes;
-		data.conference.fixed = fixed;
-	}
-	else
-	if (!strcmp(option, "destroy")) {
-		data.conference.option = CONF_DESTROY;
-	}
-	else {
-		data.conference.option = CONF_UNKNOWN;
-	}
-	if (name ==NULL) data.conference.name[0] = 0;
-	else strncpy(data.conference.name, name, 255);
-        trunkStep(TRUNK_STEP_CONFERENCE);
-	return false;
-}
 
 #ifdef CCXX_NAMESPACES
 };
