@@ -27,6 +27,7 @@ PhonedevPlay::PhonedevPlay(PhonedevTrunk *trunk) :
 Service((Trunk *)trunk, keythreads.priAudio()), URLAudio()
 {
 	reset = false;
+	id = trunk->id;
 	driver = trunk->getDriver();
 	dev = trunk->getDevice();
 }
@@ -75,6 +76,11 @@ void PhonedevPlay::initial(void)
 	int ctrl;
 	
 	trunk->getName(buffer);
+
+	if(tts)
+		if(!tts->synth(id, data))
+			Service::failure();
+
 #ifdef	POSIX_PHONEDEV
 	ctrl = data->play.volume * 10;
 	ioctl(dev, PHONE_PLAY_VOLUME, &ctrl);
@@ -85,13 +91,23 @@ retry:
 	fn = getPlayfile();
 	if(!fn)
 	{
+		if(data->play.lock)
+		{
+			cachelock.unlock();
+			data->play.lock = false;
+		}
 		if(data->play.mode == PLAY_MODE_ANY)
 			Service::success();
 		slog(Slog::levelError) << "no file" << endl;
 		Service::failure();
 	}
 	stat(fn, &ino);
-	open(fn);	
+	open(fn);
+	if(data->play.lock)
+	{
+		cachelock.unlock();
+		data->play.lock = false;
+	}	
 	if(!isOpen())
 	{
 		if(data->play.mode == PLAY_MODE_ANY || data->play.mode == PLAY_MODE_ONE)
