@@ -21,6 +21,10 @@
 
 #define CID_BUF_SZ 8000*4  // DR - up to 10 seconds of CID buffer
 
+#ifdef	VPB_RING_STATION_ONCE
+#define	vpb_ring_station_sync(a, b) vpb_ring_station_async(a, b, 0)
+#endif
+
 #ifdef	CCXX_NAMESPACES
 namespace ost {
 #endif
@@ -31,45 +35,63 @@ typedef bool (VPBTrunk::*trunkhandler_t)(TrunkEvent *event);
 
 class VPBTrunk: private Trunk
 {
-private:
+protected:
 	friend class VPBDriver;
+	friend class VPBSend;
 	friend class VPBCid;
-	friend class VPBDialer;
 	friend class VPBJoin;
 	friend class VPBTone;
+	friend class VPBPlay;
+	friend class VPBDigit;
 
 	static char status[16 * 12];
+	static unsigned _trkcount;
 
+	bool *ringIndex;
 	char name[16];
-	int _card, _port;
+	int _card, _port, _bank;
+	unsigned _trk;
 	bool inTimer;
 	bool stopped;
+	bool isStation, isRinging;
 	float	inpgain, outgain;
 	void *timer;
 	int handle;
 	unsigned bridge;
+	bool answered;
 	int x;
 	time_t lastring;
 	trunkhandler_t handler;
 	VPBTrunk *joined;
 	short cidbuf[CID_BUF_SZ]; // DR - storage for CID signal
 	char cidnbr[VPB_MAX_STR]; // DS - storage for cid parsing
+	int cidlen;
 
-	VPBTrunk(int card, int ts);
+	VPBTrunk(int card, int ts, bool sta = false);
 	~VPBTrunk();
 
 	void getName(char *buffer);
 	unsigned long getIdleTime(void);
 	unsigned getPickupTimer(void);
+	unsigned long getCapabilities(void);
+	void clearRinging(void);
 
 	bool scrRTP(void);
 	bool scrJoin(void);
 	bool scrWait(void);
-	
+	bool scrRing(void);
+	bool scrPickup(void);
+	bool scrAnswer(void);
+	bool scrDial(void);
+
+	bool endDialer(TrunkEvent *event);
+	bool digitDialer(TrunkEvent *event);	
 	bool stepHandler(TrunkEvent *event);
 	bool busyHandler(TrunkEvent *event);
 	bool idleHandler(TrunkEvent *event);
 	bool seizeHandler(TrunkEvent *event);
+	bool ringIntercom(TrunkEvent *event);
+	bool ringStation(TrunkEvent *event);
 	bool ringHandler(TrunkEvent *event);
 	bool waitHandler(TrunkEvent *event);
 	bool loadHandler(TrunkEvent *event);
@@ -80,6 +102,7 @@ private:
 	bool playwaitHandler(TrunkEvent *event);
 	bool recordHandler(TrunkEvent *event);
 	bool sleepHandler(TrunkEvent *event);
+	bool threadHandler(TrunkEvent *event);
 	bool hangupHandler(TrunkEvent *event);
 	bool answerHandler(TrunkEvent *event);
 	bool pickupHandler(TrunkEvent *event);
@@ -94,7 +117,7 @@ private:
 	void endTimer(void);
 	void setOffhook(void);
 
-	void disjoin(void);
+	void disjoin(trunkevent_t reason);
 
 	bool postEvent(TrunkEvent *event);
 	void exit(void);
@@ -103,21 +126,6 @@ private:
 	void exitThread(void);
 };
 
-class VPBDialer : private Service
-{
-private:
-	friend class VPBTrunk;
-
-	VPBTrunk *trk;
-	int handle;
-	bool reset;
-
-	void run(void);
-
-	VPBDialer(VPBTrunk *trk, int h);
-	~VPBDialer();
-};
-
 class VPBCid : private Service
 {
 private:
@@ -133,6 +141,36 @@ private:
 	~VPBCid();
 };
 
+class VPBSend : private Service
+{
+private:
+	friend class VPBTrunk;
+
+        VPBTrunk *trk;
+        int handle;
+        bool reset;
+
+        void run(void);
+
+        VPBSend(VPBTrunk *trunk, int h);
+        ~VPBSend();
+};
+
+class VPBDigit : private Service, private TimerPort
+{
+private:
+	friend class VPBTrunk;
+
+	VPBTrunk *trk;
+	int handle;
+	bool reset;
+
+	void run(void);
+
+	VPBDigit(VPBTrunk *trunk, int h);
+	~VPBDigit();
+};
+
 class VPBTone : private Service, private TimerPort
 {
 private:
@@ -169,7 +207,7 @@ class VPBPlay : private URLAudio, public Service
 private:
 	bool reset;
 	size_t bufsize, samples;
-	int handle;
+	int handle, id;
 	VPBTrunk *vpbtr; // DR
 
 	void initial(void);
@@ -199,6 +237,8 @@ public:
 class VPBConfig : public Keydata
 {
 public:
+	timeout_t	stepTimer, syncTimer;
+
 	VPBConfig();
 
 	unsigned getOffset(void)
@@ -220,32 +260,31 @@ public:
 
 	int getModel(void);
 	unsigned getCardSize(void);
-	
+
 };
 
 class VPBDriver : public Driver, public VPBConfig, public Thread
 {
 private:
-	VPBTrunk **ports;
+	VPBTrunk **ports, **trunks;
 	bool *bridges;
-	int port_count, bridge_count;
+	unsigned port_count, bridge_count;
 
 public:
 	VPBDriver();
 	~VPBDriver();
 
-	unsigned getCaps(void)
-		{return capDaemon | capPSTN | capJoin;};
-
 	void run(void);
 
 	int start(void);
 	void stop(void);
 
+	unsigned getCaps(void);
 	unsigned getBridge(int card);
 	void freeBridge(int card, unsigned bridge);
+	Trunk *getTrkNumber(const char *trk);
 
-	int getTrunkCount(void)
+	unsigned getTrunkCount(void)
 		{return port_count;};
 
 	Trunk *getTrunkPort(int id);
