@@ -710,7 +710,7 @@ bool MsgboxTrunk::loader(Trunk *trk, trunkdata_t *data)
 	if(!ext)
 		ext = trk->getSymbol(SYM_EXTENSION);
 
-	while(NULL != (name = dir->getName()))
+	while(NULL != (name = (char *)dir->getName()))
 	{
 		Thread::yield();
 		cp = strrchr(name, '.');
