@@ -72,12 +72,21 @@ int TrunkImage::aRead(char *buffer, size_t len, timeout_t timeout)
 }
 #endif
 
+#ifndef COMMON_64_CLEAN	
 int TrunkImage::read(unsigned char *buffer, int len)
 {
 	URLStream::read((char *)buffer, len);
 	return gcount();
 }
 
+#else
+int TrunkImage::read(unsigned char *buffer, size_t len)       
+{
+        URLStream::read((char *)buffer, len);
+        return gcount();
+}
+#endif
+
 void TrunkImage::purge(void)
 {
 	URLStream::close();
