@@ -1267,6 +1267,10 @@ bool Trunk::ifFeature(ScriptInterp *interp, const char *v)
         if(!stricmp(v, "station") && (((Trunk *)(interp))->getCapabilities() & TRUNK_CAP_STATION))
                 return true;
 
+	if(!stricmp(v, "reroute") && (driver->getCaps() & Driver::capReroute))
+               return true;
+
+
 	return false;
 }
 
